# Generated by Django 5.2.7 on 2025-10-09 15:24

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "django_cfg_knowbase",
            "0002_archiveitem_archiveitemchunk_documentarchive_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="documentarchive",
            name="archive_type",
            field=models.CharField(
                choices=[
                    ("zip", "ZIP"),
                    ("tar", "TAR"),
                    ("tar.gz", "TAR GZ"),
                    ("tar.bz2", "TAR BZ2"),
                ],
                help_text="Archive format",
                max_length=20,
            ),
        ),
    ]
