# Generated by Django 5.2.4 on 2025-09-05 06:25

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_cfg_support", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="message",
            name="ticket",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="messages",
                to="django_cfg_support.ticket",
            ),
        ),
    ]
